@@ -215,7 +215,7 @@ class CircularClient:
         )
         return self._proccess_response(res)
 
-    def get_user(self, symbol, account_name, sig_generator):
+    def get_user(self, symbol, account_name, sig_generator=None):
         path = '/v1/project/{0}/users/{1}'.format(symbol, account_name)
         headers = self._get_headers()
 
